==> haskell-yesod-core-1.6.27.1-105-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.27.1
visibility:           public
id:                   yesod-core-1.6.27.1-KtBa6Xls8994lQw12Q4B1F
key:                  yesod-core-1.6.27.1-KtBa6Xls8994lQw12Q4B1F
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  f3eabd7fb923be15a00a0882ab7179e9
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.27.1-KtBa6Xls8994lQw12Q4B1F
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-aeson-2.1.0.0-BEiLkT0rdCWAen0nBrmaBS
    auto-update-0.1.6-88T3ReDBoup7kx6uceSFG6 base-4.18.2.1
    blaze-html-0.9.2.0-5pCa6Zd2ytCBxKPCiAVcIx
    blaze-markup-0.8.3.0-JJ5r8tycCxXJkM0kXa0ha9 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    clientsession-0.9.3.0-F81IgejuppZIVdHDsmZ7W4
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6 containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w mtl-2.3.1
    parsec-3.1.16.1 path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    shakespeare-2.1.7-EQa3S9NEyAK816psNg58s0 template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    wai-extra-3.1.18-1ANzYYqVephHj2C1lo6Zwk
    wai-logger-2.5.0-VBPNbjn5lcBUCsraseoRs
    warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.6.27.1-107-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.27.1
visibility:           public
id:                   yesod-core-1.6.27.1-4gpTrKJARZw1tOAQMfFW4B
key:                  yesod-core-1.6.27.1-4gpTrKJARZw1tOAQMfFW4B
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  5b096a4dba3efd25d207508c5264f55b
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.27.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.27.1-4gpTrKJARZw1tOAQMfFW4B
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    attoparsec-aeson-2.2.0.0-1Dj4q6tPpHs6SGokkiN3Ch
    auto-update-0.1.6-KtJVhP9gwX02GwwOhHipKc base-4.18.2.1
    blaze-html-0.9.2.0-AqjQr4Ps51QD51ybemU3ZY
    blaze-markup-0.8.3.0-K7wUMOM5SyIFeEdepQMdjc bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8PStX6cixKCLkUJoPuARL
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    clientsession-0.9.3.0-7Qaz243uinzAxbsZKCsGvF
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-0.7.1.3-Ihbp7WFUy146w4K1utdfXl deepseq-1.4.8.1
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    fast-logger-3.2.4-Jiy7JoGUrfbVNzVDnbkpD
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-logger-0.3.42-JqeTk6zPcDZE7ttxNu3qt7 mtl-2.3.1
    parsec-3.1.16.1 path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    primitive-0.9.1.0-7ibydtGngalFw21zVTsTma
    random-1.2.1.3-6l1YOhgkyj83HD6td8a68Q
    resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77
    shakespeare-2.1.7-2tYm0ZnKNHbCMeQLiFCieX template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-A9X47MkwTFf6xepaAigQ6V
    unliftio-0.2.25.1-DOqhOSuyr6GEMTQhxoBZ0V
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6
    wai-3.2.4-BLc210LwMQhDvJHRqgIjev
    wai-extra-3.1.18-2NqKPuFl5Jd2v0if4D3Rrq
    wai-logger-2.5.0-7XRbr5ukpDX4gn1KareYel
    warp-3.4.0-Js0YTJVu1i5Lh7vUHNAyGE
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
